==> openutils-hibernate-security-0.0.4-sources.jar: it/openutils/hibernate/security/filter/utils/SecurityRuleUtils.java <==
/*
 * Copyright (c) Openmind.  All rights reserved. http://www.openmindonline.it
 */
package it.openutils.hibernate.security.filter.utils;

import it.openutils.hibernate.security.dataobject.PermissionEnum;
import it.openutils.hibernate.security.dataobject.SecurityRule;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.acegisecurity.Authentication;
import org.acegisecurity.ConfigAttribute;
import org.acegisecurity.ConfigAttributeDefinition;
import org.acegisecurity.GrantedAuthority;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * @author fcarone
 * @version $Id: SecurityRuleUtils.java 672 2008-02-20 17:14:54Z fcarone $
 */
public class SecurityRuleUtils
{
    /**
     * Logger.
     */
    private Logger log = LoggerFactory.getLogger(SecurityRuleUtils.class);

    /**
     * @param rules The list of rules to check
     * @param config The config attribute to check the rules against
     * @return True if any of the rules matches the given config attribute, false otherwise.
     */
    @SuppressWarnings("unchecked")
    public boolean checkPermissions(List<SecurityRule> rules, ConfigAttributeDefinition config)
    {
        log.debug("Evaluation permissions");
        Iterator iterator = config.getConfigAttributes();
        while (iterator.hasNext())
        {
            String attribute = ((ConfigAttribute) iterator.next()).getAttribute();
            for (SecurityRule rule : rules)
            {
                for (PermissionEnum permission : rule.getPermissions())
                {
                    if (StringUtils.equals(permission.getValue(), attribute))
                    {
                        log.debug("Matching permission: {}", permission.getValue());
                        return true;
                    }
                }
            }
        }
        log.debug("No matching permissions found.");
        return false;
    }

    /**
     * @param rules The list of rules to check
     * @param argument The object to check the rules against
     * @return True if any of the rules matches the given object, false otherwise.
     */
    public boolean checkRules(List<SecurityRule> rules, Object argument)
    {
        log.debug("Evaluating rules.");
        try
        {
            for (SecurityRule rule : rules)
            {
                String objProperty = BeanUtils.getSimpleProperty(argument, rule.getProperty());
                switch (rule.getModifier())
                {
                    case EQUALS:
                        if (StringUtils.equals(objProperty, rule.getValue()))
                        {
                            log.debug("Matching rule found: {}", rule);
                            return true;
                        }
                        break;
                    case NOT:
                        if (!StringUtils.equals(objProperty, rule.getValue()))
                        {
                            log.debug("Matching rule found: {}", rule);
                            return true;
                        }
                        break;                        
                    default:
                        throw new RuntimeException("Modifier " + rule.getModifier() + " is not recognized");
                }
            }
        }
        catch (NoSuchMethodException e)
        {
            log.error("{}", e);
        }
        catch (IllegalAccessException e)
        {
            log.error("{}", e);
        }
        catch (InvocationTargetException e)
        {
            log.error("{}", e);
        }
        log.debug("No matching rules found.");
        return false;
    }


    /**
     * @param authentication The authentication method
     * @return The collection of roles contained in the authentication
     */
    public List<String> getRolesFromAuthentication(Authentication authentication)
    {
        List<String> roles = new ArrayList<String>();
        for (GrantedAuthority authority : authentication.getAuthorities())
        {
            log.debug("Granted authority for user {}: {}", authentication.getName(), authority.getAuthority());
            roles.add(authority.getAuthority());
        }
        return roles;
    }


    /**
     * @param object The object to get the name from
     * @return The object name
     */
    public String getClassName(Object object)
    {
        // is this class a CGLib proxy?
        if (StringUtils.contains(object.getClass().getName(), "$$"))
        {
            return StringUtils.substringBefore(object.getClass().getName(), "$$");
        }
        return object.getClass().getName();
    }
}

==> openutils-hibernate-security-0.0.5-sources.jar: it/openutils/hibernate/security/filter/utils/SecurityRuleUtils.java <==
/*
 * Copyright Openmind http://www.openmindonline.it
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package it.openutils.hibernate.security.filter.utils;

import it.openutils.hibernate.security.dataobject.PermissionEnum;
import it.openutils.hibernate.security.dataobject.SecurityRule;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.acegisecurity.Authentication;
import org.acegisecurity.ConfigAttribute;
import org.acegisecurity.ConfigAttributeDefinition;
import org.acegisecurity.GrantedAuthority;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * @author fcarone
 * @version $Id: SecurityRuleUtils.java 698 2008-02-25 14:08:00Z fcarone $
 */
public class SecurityRuleUtils
{
    /**
     * Logger.
     */
    private Logger log = LoggerFactory.getLogger(SecurityRuleUtils.class);

    /**
     * @param rules The list of rules to check
     * @param config The config attribute to check the rules against
     * @return True if any of the rules matches the given config attribute, false otherwise.
     */
    @SuppressWarnings("unchecked")
    public boolean checkPermissions(List<SecurityRule> rules, ConfigAttributeDefinition config)
    {
        log.debug("Evaluation permissions");
        Iterator iterator = config.getConfigAttributes();
        while (iterator.hasNext())
        {
            String attribute = ((ConfigAttribute) iterator.next()).getAttribute();
            for (SecurityRule rule : rules)
            {
                if (!rule.isEnabled())
                {
                    log.debug("Skipping disabled rule {}", rule);
                    continue;
                }
                for (PermissionEnum permission : rule.getPermissions())
                {
                    if (StringUtils.equals(permission.getValue(), attribute))
                    {
                        log.debug("Matching permission: {}", permission.getValue());
                        return true;
                    }
                }
            }
        }
        log.debug("No matching permissions found.");
        return false;
    }

    /**
     * @param rules The list of rules to check
     * @param argument The object to check the rules against
     * @return True if any of the rules matches the given object, false otherwise.
     */
    public boolean checkRules(List<SecurityRule> rules, Object argument)
    {
        log.debug("Evaluating rules.");
        try
        {
            for (SecurityRule rule : rules)
            {
                if (!rule.isEnabled())
                {
                    continue;
                }
                String objProperty = BeanUtils.getSimpleProperty(argument, rule.getProperty());
                switch (rule.getModifier())
                {
                    case EQUALS:
                        if (StringUtils.equals(objProperty, rule.getValue()))
                        {
                            log.debug("Matching rule found: {}", rule);
                            return true;
                        }
                        break;
                    case NOT:
                        if (!StringUtils.equals(objProperty, rule.getValue()))
                        {
                            log.debug("Matching rule found: {}", rule);
                            return true;
                        }
                        break;
                    default:
                        throw new RuntimeException("Modifier " + rule.getModifier() + " is not recognized");
                }
            }
        }
        catch (NoSuchMethodException e)
        {
            log.error("{}", e);
        }
        catch (IllegalAccessException e)
        {
            log.error("{}", e);
        }
        catch (InvocationTargetException e)
        {
            log.error("{}", e);
        }
        log.debug("No matching rules found.");
        return false;
    }


    /**
     * @param authentication The authentication method
     * @return The collection of roles contained in the authentication
     */
    public List<String> getRolesFromAuthentication(Authentication authentication)
    {
        List<String> roles = new ArrayList<String>();
        for (GrantedAuthority authority : authentication.getAuthorities())
        {
            log.debug("Granted authority for user {}: {}", authentication.getName(), authority.getAuthority());
            roles.add(authority.getAuthority());
        }
        return roles;
    }


    /**
     * @param object The object to get the name from
     * @return The object name
     */
    public String getClassName(Object object)
    {
        // is this class a CGLib proxy?
        if (StringUtils.contains(object.getClass().getName(), "$$"))
        {
            return StringUtils.substringBefore(object.getClass().getName(), "$$");
        }
        return object.getClass().getName();
    }
}
